@@ -1,18 +1,21 @@
 """Provide a model for the Z-Wave JS node."""
-from typing import TYPE_CHECKING, Any, List, Optional, TypedDict, Union, cast
+from typing import TYPE_CHECKING, Any, Dict, List, Optional, TypedDict, Union, cast
+from zwave_js_server.const import CommandClass
 
+from ..exceptions import UnparseableValue, UnwriteableValue
 from ..event import Event, EventBase
 from .device_class import DeviceClass, DeviceClassDataType
 from .device_config import DeviceConfig, DeviceConfigDataType
 from .endpoint import Endpoint, EndpointDataType
 from .notification import Notification, NotificationDataType
 from .value import (
+    ConfigurationValue,
     MetaDataType,
     Value,
     ValueDataType,
     ValueMetadata,
     ValueNotification,
-    get_value_id,
+    _get_value_id_from_dict,
 )
 
 if TYPE_CHECKING:
@@ -66,9 +69,17 @@ class Node(EventBase):
         super().__init__()
         self.client = client
         self.data = data
-        self.values = {
-            get_value_id(self, val): Value(self, val) for val in data["values"]
-        }
+        self.values: Dict[str, Union[Value, ConfigurationValue]] = {}
+        for val in data["values"]:
+            value_id = _get_value_id_from_dict(self, val)
+            try:
+                if val["commandClass"] == CommandClass.CONFIGURATION:
+                    self.values[value_id] = ConfigurationValue(self, val)
+                else:
+                    self.values[value_id] = Value(self, val)
+            except UnparseableValue:
+                # If we can't parse the value, don't store it
+                pass
 
     def __repr__(self) -> str:
         """Return the representation."""
@@ -234,6 +245,24 @@ class Node(EventBase):
         """Return the interview_attempts."""
         return self.data.get("interviewAttempts")
 
+    def get_command_class_values(
+        self, command_class: CommandClass, endpoint: int = None
+    ) -> Dict[str, Union[ConfigurationValue, Value]]:
+        """Return all values for a given command class."""
+        return {
+            value_id: value
+            for value_id, value in self.values.items()
+            if value.command_class == command_class
+            and (endpoint is None or value.endpoint == endpoint)
+        }
+
+    def get_configuration_values(self) -> Dict[str, ConfigurationValue]:
+        """Return all configuration values for a node."""
+        return cast(
+            Dict[str, ConfigurationValue],
+            self.get_command_class_values(CommandClass.CONFIGURATION),
+        )
+
     def receive_event(self, event: Event) -> None:
         """Receive an event."""
         self._handle_event_protocol(event)
@@ -246,6 +275,10 @@ class Node(EventBase):
         # a value may be specified as value_id or the value itself
         if not isinstance(val, Value):
             val = self.values[val]
+
+        if val.metadata.writeable is False:
+            raise UnwriteableValue
+
         # the value object needs to be send to the server
         result = await self.client.async_send_command(
             {
@@ -259,7 +292,7 @@ class Node(EventBase):
 
     async def async_refresh_info(self) -> None:
         """Send refreshInfo command to Node."""
-        await self.client.async_send_json_message(
+        await self.client.async_send_command(
             {
                 "command": "node.refresh_info",
                 "nodeId": self.node_id,
@@ -295,7 +328,7 @@ class Node(EventBase):
 
     async def async_abort_firmware_update(self) -> None:
         """Send abortFirmwareUpdate command to Node."""
-        await self.client.async_send_json_message(
+        await self.client.async_send_command(
             {
                 "command": "node.abort_firmware_update",
                 "nodeId": self.node_id,
@@ -338,7 +371,7 @@ class Node(EventBase):
         self.data.update(event.data["nodeState"])
         # update/add values
         for value_state in event.data["nodeState"]["values"]:
-            value_id = get_value_id(self, value_state)
+            value_id = _get_value_id_from_dict(self, value_state)
             value = self.values.get(value_id)
             if value is None:
                 self.values[value_id] = Value(self, value_state)
@@ -352,7 +385,7 @@ class Node(EventBase):
 
     def handle_value_updated(self, event: Event) -> None:
         """Process a node value updated event."""
-        value = self.values.get(get_value_id(self, event.data["args"]))
+        value = self.values.get(_get_value_id_from_dict(self, event.data["args"]))
         if value is None:
             # received update for unknown value
             # should not happen but just in case, treat like added value
@@ -363,12 +396,14 @@ class Node(EventBase):
 
     def handle_value_removed(self, event: Event) -> None:
         """Process a node value removed event."""
-        event.data["value"] = self.values.pop(get_value_id(self, event.data["args"]))
+        event.data["value"] = self.values.pop(
+            _get_value_id_from_dict(self, event.data["args"])
+        )
 
     def handle_value_notification(self, event: Event) -> None:
         """Process a node value notification event."""
         # append metadata if value metadata is available
-        value = self.values.get(get_value_id(self, event.data["args"]))
+        value = self.values.get(_get_value_id_from_dict(self, event.data["args"]))
         if value and value.data.get("metadata"):
             event.data["args"]["metadata"] = value.data["metadata"]
         event.data["value_notification"] = ValueNotification(self, event.data["args"])
